name change related issues
authorswa <swa@users.sourceforge.net>
Sun, 24 Mar 2002 13:34:31 +0000 (13:34 +0000)
committerswa <swa@users.sourceforge.net>
Sun, 24 Mar 2002 13:34:31 +0000 (13:34 +0000)
cgiedit.c
config.h.in
config.h.win
privoxy-rh.spec

index 85f2586..a7cbd7d 100644 (file)
--- a/cgiedit.c
+++ b/cgiedit.c
@@ -1,4 +1,4 @@
-const char cgiedit_rcs[] = "$Id: cgiedit.c,v 1.21 2002/03/22 18:02:48 jongfoster Exp $";
+const char cgiedit_rcs[] = "$Id: cgiedit.c,v 1.22 2002/03/24 13:25:43 swa Exp $";
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/cgiedit.c,v $
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/cgiedit.c,v $
@@ -42,6 +42,9 @@ const char cgiedit_rcs[] = "$Id: cgiedit.c,v 1.21 2002/03/22 18:02:48 jongfoster
  *
  * Revisions   :
  *    $Log: cgiedit.c,v $
  *
  * Revisions   :
  *    $Log: cgiedit.c,v $
+ *    Revision 1.22  2002/03/24 13:25:43  swa
+ *    name change related issues
+ *
  *    Revision 1.21  2002/03/22 18:02:48  jongfoster
  *    Fixing remote toggle
  *
  *    Revision 1.21  2002/03/22 18:02:48  jongfoster
  *    Fixing remote toggle
  *
@@ -2446,7 +2449,7 @@ jb_err cgi_edit_actions(struct client_state *csp,
    }
 
    /* FIXME: Incomplete */
    }
 
    /* FIXME: Incomplete */
-   rsp->status = strdup("302 Local Redirect from Junkbuster");
+   rsp->status = strdup("302 Local Redirect from Privoxy");
    if (rsp->status == NULL)
    {
       return JB_ERR_MEMORY;
    if (rsp->status == NULL)
    {
       return JB_ERR_MEMORY;
@@ -3218,7 +3221,7 @@ jb_err cgi_edit_actions_submit(struct client_state *csp,
       return JB_ERR_MEMORY;
    }
 
       return JB_ERR_MEMORY;
    }
 
-   rsp->status = strdup("302 Local Redirect from Junkbuster");
+   rsp->status = strdup("302 Local Redirect from Privoxy");
    if (rsp->status == NULL)
    {
       free(target);
    if (rsp->status == NULL)
    {
       free(target);
@@ -3340,7 +3343,7 @@ jb_err cgi_edit_actions_url(struct client_state *csp,
       return JB_ERR_MEMORY;
    }
 
       return JB_ERR_MEMORY;
    }
 
-   rsp->status = strdup("302 Local Redirect from Junkbuster");
+   rsp->status = strdup("302 Local Redirect from Privoxy");
    if (rsp->status == NULL)
    {
       free(target);
    if (rsp->status == NULL)
    {
       free(target);
@@ -3479,7 +3482,7 @@ jb_err cgi_edit_actions_add_url(struct client_state *csp,
       return JB_ERR_MEMORY;
    }
 
       return JB_ERR_MEMORY;
    }
 
-   rsp->status = strdup("302 Local Redirect from Junkbuster");
+   rsp->status = strdup("302 Local Redirect from Privoxy");
    if (rsp->status == NULL)
    {
       free(target);
    if (rsp->status == NULL)
    {
       free(target);
@@ -3595,7 +3598,7 @@ jb_err cgi_edit_actions_remove_url(struct client_state *csp,
       return JB_ERR_MEMORY;
    }
 
       return JB_ERR_MEMORY;
    }
 
-   rsp->status = strdup("302 Local Redirect from Junkbuster");
+   rsp->status = strdup("302 Local Redirect from Privoxy");
    if (rsp->status == NULL)
    {
       free(target);
    if (rsp->status == NULL)
    {
       free(target);
@@ -3727,7 +3730,7 @@ jb_err cgi_edit_actions_section_remove(struct client_state *csp,
       return JB_ERR_MEMORY;
    }
 
       return JB_ERR_MEMORY;
    }
 
-   rsp->status = strdup("302 Local Redirect from Junkbuster");
+   rsp->status = strdup("302 Local Redirect from Privoxy");
    if (rsp->status == NULL)
    {
       free(target);
    if (rsp->status == NULL)
    {
       free(target);
@@ -3901,7 +3904,7 @@ jb_err cgi_edit_actions_section_add(struct client_state *csp,
       return JB_ERR_MEMORY;
    }
 
       return JB_ERR_MEMORY;
    }
 
-   rsp->status = strdup("302 Local Redirect from Junkbuster");
+   rsp->status = strdup("302 Local Redirect from Privoxy");
    if (rsp->status == NULL)
    {
       free(target);
    if (rsp->status == NULL)
    {
       free(target);
@@ -4100,7 +4103,7 @@ jb_err cgi_edit_actions_section_swap(struct client_state *csp,
       return JB_ERR_MEMORY;
    }
 
       return JB_ERR_MEMORY;
    }
 
-   rsp->status = strdup("302 Local Redirect from Junkbuster");
+   rsp->status = strdup("302 Local Redirect from Privoxy");
    if (rsp->status == NULL)
    {
       free(target);
    if (rsp->status == NULL)
    {
       free(target);
index 4f8b803..8f4b184 100644 (file)
@@ -3,7 +3,7 @@
 #define CONFIG_H_INCLUDED
 /*********************************************************************
  *
 #define CONFIG_H_INCLUDED
 /*********************************************************************
  *
- * File        :  $Source: /cvsroot/ijbswa/current/acconfig.h,v $
+ * File        :  $Source: /cvsroot/ijbswa/current/config.h.in,v $
  *
  * Purpose     :  This file should be the first thing included in every
  *                .c file.  (Before even system headers).  It contains 
  *
  * Purpose     :  This file should be the first thing included in every
  *                .c file.  (Before even system headers).  It contains 
@@ -12,7 +12,7 @@
  *                getting ludicrously long with feature defines.
  *
  * Copyright   :  Written by and Copyright (C) 2001 the SourceForge
  *                getting ludicrously long with feature defines.
  *
  * Copyright   :  Written by and Copyright (C) 2001 the SourceForge
- *                IJBSWA team.  http://ijbswa.sourceforge.net
+ *                Privoxy team.  http://ijbswa.sourceforge.net
  *
  *                Based on the Internet Junkbuster originally written
  *                by and Copyright (C) 1997 Anonymous Coders and 
  *
  *                Based on the Internet Junkbuster originally written
  *                by and Copyright (C) 1997 Anonymous Coders and 
  *                Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  * Revisions   :
  *                Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  * Revisions   :
- *    $Log: acconfig.h,v $
+ *    $Log: config.h.in,v $
+ *    Revision 1.20  2002/03/22 18:12:53  jongfoster
+ *    Bumping version number to 2.9.12
+ *
  *    Revision 1.18  2002/03/08 16:40:28  oes
  *    Added FEATURE_NO_GIFS
  *
  *    Revision 1.18  2002/03/08 16:40:28  oes
  *    Added FEATURE_NO_GIFS
  *
 #undef FEATURE_STATISTICS
 
 /*
 #undef FEATURE_STATISTICS
 
 /*
* Allow JunkBuster to be "disabled" so it is just a normal non-blocking
  * non-anonymizing proxy.  This is useful if you're trying to access a
  * blocked or broken site - just change the setting in the config file,
  * or use the handy "Disable" menu option in the Windows GUI.
  * non-anonymizing proxy.  This is useful if you're trying to access a
  * blocked or broken site - just change the setting in the config file,
  * or use the handy "Disable" menu option in the Windows GUI.
index 6923b9e..79294eb 100755 (executable)
@@ -11,7 +11,7 @@
  *                getting ludicrously long with feature defines.
  *
  * Copyright   :  Written by and Copyright (C) 2001 the SourceForge
  *                getting ludicrously long with feature defines.
  *
  * Copyright   :  Written by and Copyright (C) 2001 the SourceForge
- *                IJBSWA team.  http://ijbswa.sourceforge.net
+ *                Privoxy team.  http://ijbswa.sourceforge.net
  *
  *                Based on the Internet Junkbuster originally written
  *                by and Copyright (C) 1997 Anonymous Coders and 
  *
  *                Based on the Internet Junkbuster originally written
  *                by and Copyright (C) 1997 Anonymous Coders and 
@@ -37,6 +37,9 @@
  *
  * Revisions   :
  *    $Log: config.h.win,v $
  *
  * Revisions   :
  *    $Log: config.h.win,v $
+ *    Revision 1.16  2002/03/16 14:27:22  jongfoster
+ *    Ignoring a very common warning.
+ *
  *    Revision 1.15  2002/03/13 00:28:32  jongfoster
  *    Hiding all the warnings generated by #include<windows.h>
  *
  *    Revision 1.15  2002/03/13 00:28:32  jongfoster
  *    Hiding all the warnings generated by #include<windows.h>
  *
index a8d39fc..39323bc 100644 (file)
@@ -1,4 +1,4 @@
-# $Id: privoxy-rh.spec,v 1.2 2002/03/24 11:40:14 swa Exp $
+# $Id: privoxy-rh.spec,v 1.3 2002/03/24 12:56:21 swa Exp $
 #
 # Written by and Copyright (C) 2001 the SourceForge
 # PRIVOXY team.  http://ijbswa.sourceforge.net
 #
 # Written by and Copyright (C) 2001 the SourceForge
 # PRIVOXY team.  http://ijbswa.sourceforge.net
@@ -89,7 +89,7 @@ mkdir -p %{buildroot}%{_sbindir} \
 ## Gziping the documentation files is not recomended - morcego
 #gzip README AUTHORS ChangeLog %{name}.1 || /bin/true
 
 ## Gziping the documentation files is not recomended - morcego
 #gzip README AUTHORS ChangeLog %{name}.1 || /bin/true
 
-install -s -m 744 jbng %{buildroot}%{_sbindir}/jbng
+install -s -m 744 %{name} %{buildroot}%{_sbindir}/%{name}
 
 ## We need to change the man section internaly on the manpage
 ## -- morcego (sugestion by Hal Burgiss)
 
 ## We need to change the man section internaly on the manpage
 ## -- morcego (sugestion by Hal Burgiss)
@@ -189,7 +189,7 @@ id privoxy > /dev/null 2>&1 && /usr/sbin/userdel privoxy || /bin/true
 %dir %{privoxyconf}/templates
 %attr(0744,privoxy,privoxy) %dir %{_localstatedir}/log/%{name}
 
 %dir %{privoxyconf}/templates
 %attr(0744,privoxy,privoxy) %dir %{_localstatedir}/log/%{name}
 
-%attr(0744,privoxy,privoxy)%{_sbindir}/jbng
+%attr(0744,privoxy,privoxy)%{_sbindir}/%{name}
 
 # We should not use wildchars here. This could mask missing files problems
 # -- morcego
 
 # We should not use wildchars here. This could mask missing files problems
 # -- morcego
@@ -480,6 +480,9 @@ id privoxy > /dev/null 2>&1 && /usr/sbin/userdel privoxy || /bin/true
        additional "-r @" flag.
 
 # $Log: privoxy-rh.spec,v $
        additional "-r @" flag.
 
 # $Log: privoxy-rh.spec,v $
+# Revision 1.3  2002/03/24 12:56:21  swa
+# name change related issues.
+#
 # Revision 1.2  2002/03/24 11:40:14  swa
 # name change
 #
@@ -12,7 +12,7 @@
 
 /*
- * Allow JunkBuster to be "disabled" so it is just a normal non-blocking
+ * Allow Privoxy to be "disabled" so it is just a normal non-blocking
  * non-anonymizing proxy.  This is useful if you're trying to access a
  * blocked or broken site - just change the setting in the config file,
 # Revision 1.2  2002/03/24 11:40:14  swa
 # name change
 #